==> peek-plugin-graphdb-2.5.1.tar.gz: peek-plugin-graphdb-2.5.1/peek_plugin_graphdb/_private/server/admin_backend/ViewSegmentHandler.py <==
import logging

from peek_plugin_graphdb._private.PluginNames import graphDbFilt
from peek_plugin_graphdb._private.storage.GraphDbSegment import GraphDbSegment
from vortex.TupleSelector import TupleSelector
from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
from vortex.sqla_orm.OrmCrudHandler import OrmCrudHandler, OrmCrudHandlerExtension

logger = logging.getLogger(__name__)

# This dict matches the definition in the Admin angular app.
filtKey = {"key": "admin.Edit.GraphDbLinkedSegment"}
filtKey.update(graphDbFilt)


# This is the CRUD hander
class __CrudHandler(OrmCrudHandler):
    pass


class __ExtUpdateObservable(OrmCrudHandlerExtension):
    """ Update Observable ORM Crud Extension

    This extension is called after events that will alter data,
    it then notifies the observer.

    """
    def __init__(self, tupleDataObserver: TupleDataObservableHandler):
        self._tupleDataObserver = tupleDataObserver

    def _tellObserver(self, tuple_, tuples, session, payloadFilt):
        selector = {}
        # Copy any filter values into the selector
        # selector["lookupName"] = payloadFilt["lookupName"]
        tupleSelector = TupleSelector(GraphDbSegment.tupleName(),
                                      selector)
        self._tupleDataObserver.notifyOfTupleUpdate(tupleSelector)
        return True

    afterUpdateCommit = _tellObserver
    afterDeleteCommit = _tellObserver


# This method creates an instance of the handler class.
def makeSegmentTableHandler(tupleObservable, dbSessionCreator):
    handler = __CrudHandler(dbSessionCreator, GraphDbSegment,
                            filtKey, retreiveAll=True)

    logger.debug("Started")
    handler.addExtension(GraphDbSegment, __ExtUpdateObservable(tupleObservable))
    return handler

==> peek-plugin-graphdb-3.1.2.tar.gz: peek-plugin-graphdb-3.1.2/peek_plugin_graphdb/_private/server/admin_backend/ViewSegmentHandler.py <==
import logging

from peek_plugin_graphdb._private.PluginNames import graphDbFilt
from peek_plugin_graphdb._private.storage.GraphDbSegment import GraphDbSegment
from vortex.TupleSelector import TupleSelector
from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
from vortex.sqla_orm.OrmCrudHandler import OrmCrudHandler, OrmCrudHandlerExtension

logger = logging.getLogger(__name__)

# This dict matches the definition in the Admin angular app.
filtKey = {"key": "admin.Edit.GraphDbLinkedSegment"}
filtKey.update(graphDbFilt)


# This is the CRUD hander
class __CrudHandler(OrmCrudHandler):
    pass


class __ExtUpdateObservable(OrmCrudHandlerExtension):
    """Update Observable ORM Crud Extension

    This extension is called after events that will alter data,
    it then notifies the observer.

    """

    def __init__(self, tupleDataObserver: TupleDataObservableHandler):
        self._tupleDataObserver = tupleDataObserver

    def _tellObserver(self, tuple_, tuples, session, payloadFilt):
        selector = {}
        # Copy any filter values into the selector
        # selector["lookupName"] = payloadFilt["lookupName"]
        tupleSelector = TupleSelector(GraphDbSegment.tupleName(), selector)
        self._tupleDataObserver.notifyOfTupleUpdate(tupleSelector)
        return True

    afterUpdateCommit = _tellObserver
    afterDeleteCommit = _tellObserver


# This method creates an instance of the handler class.
def makeSegmentTableHandler(tupleObservable, dbSessionCreator):
    handler = __CrudHandler(dbSessionCreator, GraphDbSegment, filtKey, retreiveAll=True)

    logger.debug("Started")
    handler.addExtension(GraphDbSegment, __ExtUpdateObservable(tupleObservable))
    return handler
